(* Prozess mit Anzeigefenster starten
   ==================================

    Dr. J. Rathlev, D-24222 Schwentinental (info(a)rathlev-home.de)

   The contents of this file may be used under the terms of the
   Mozilla Public License ("MPL") or
   GNU Lesser General Public License Version 2 or later (the "LGPL")

   Software distributed under this License is distributed on an "AS IS" basis,
   WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
   the specific language governing rights and limitations under the License.

   Vers. 1 - Mai 2005
         1.1 - Aug. 2005 : return process exit code
   *)

unit WinExecute;

interface

uses Winapi.Windows, Vcl.Forms, Vcl.StdCtrls;

const
  UserError = $20000000;

function ExecuteProcess (CmdLine,WorkDir : string; ShowWin : boolean; WaitTime : integer;
                         IgnoreTimeout : boolean = false; OutMemo : TMemo = nil) : HResult;

function StartProcess (CmdLine,WorkDir : string; AShow : boolean) : THandle;

function StartProcessAsUser (UserName,Domain,Password,CmdLine,WorkDir : WideString;
                             AShow : boolean) : THandle;

procedure StopProcess (h : THandle);

implementation

uses Show, WinUtils, System.SysUtils, WinApiUtils, UnitStrings;

{ ------------------------------------------------------------------- }
// Prozess mit Befehlszeile "CmdLine" starten
// ShowWin  = true : Anzeige von StdOut
//          = false: Keine Anzeige von StdOut
// WaitTime > 0 : Warte auf das Ende des Prozesses fr max. "WaitTime" Sekunden
//          = 0 : Warten auf den gestarteten Prozess
// Result: = 0: ok
//         > 0 :  Bit 29 ($20000000) gesetzt : ExitCode = Result and $FF
//                sonst  Systemfehler von GetLastErr (siehe SysErrorMessage)
function ExecuteProcess (CmdLine,WorkDir : string; ShowWin : boolean; WaitTime : integer;
                         IgnoreTimeout : boolean = false; OutMemo : TMemo = nil) : HResult;
const
  BUFSIZE = 1024;
var
  si        : TStartupInfo;
  pi        : TProcessInformation;
  s         : string;
  saAttr    : TSecurityAttributes;
  hChildStdoutRd,hChildStdoutWr,
  hChildStdoutRdDup  : THandle;
  chBuf     : array [0..BUFSIZE] of AnsiChar;
  dwread,ec : DWord;
  frmShow   : TfrmShow;
begin
// Set the bInheritHandle flag so pi         pe handles are inherited.
  saAttr.nLength:=sizeof(SECURITY_ATTRIBUTES);
  saAttr.bInheritHandle:=TRUE;
  saAttr.lpSecurityDescriptor:=nil;

 // The steps for redirecting child process's STDOUT:
 //     1. Save current STDOUT, to be restored later.
 //     2. Create anonymous pipe to be STDOUT for child process.
 //     3. Set STDOUT of the parent process to be write handle to
 //        the pipe, so it is inherited by the child process.
 //        (this is made instead by CreateProcess - StartupInfo, JR)
 //     4. Create a noninheritable duplicate of the read handle and
 //        close the inheritable read handle.

// Save the handle to the current STDOUT.
//    hSaveStdout:=GetStdHandle(STD_OUTPUT_HANDLE);
// Create a pipe for the child process's STDOUT.
  if not CreatePipe(hChildStdoutRd,hChildStdoutWr,@saAttr, 0) then begin
    if ShowWin then ErrorDialog(rsExecuteError,rsCreatePipeError);
    Result:=ERROR_PIPE_CONNECTED;
    exit;
    end;
// Set a write handle to the pipe to be STDOUT.
{    if not SetStdHandle(STD_OUTPUT_HANDLE,hChildStdoutWr) then begin
    ShowError('Redirecting STDOUT failed'); exit;
    end;
    }
// Create noninheritable read handle and close the inheritable read
// handle.
  if not DuplicateHandle(GetCurrentProcess,hChildStdoutRd,GetCurrentProcess,
                         @hChildStdoutRdDup , 0, FALSE,
                         DUPLICATE_SAME_ACCESS) then begin
    if ShowWin then ErrorDialog(rsExecuteError,rsDupHandleError);
    Result:=E_HANDLE;
    exit;
    end;
  CloseHandle(hChildStdoutRd);

// Create process to start Program
  FillChar(si, SizeOf(TStartupInfo), 0);
  with si do begin
    cb:=Sizeof(TStartupInfo);
    dwFlags:=STARTF_USESHOWWINDOW;
    if ShowWin then wShowWindow:=SW_SHOWDEFAULT
    else begin
      dwFlags:=dwFlags or STARTF_USESTDHANDLES;
      wShowWindow:=SW_HIDE;
      end;
    hStdOutput :=hChildStdoutWr;
    end;

  if CreateProcess(nil,                // Anwendungsname
                   pchar(CmdLine),
                   nil,                // Security
                   nil,                // Security
                   true,               // use InheritHandles
//                   CREATE_NEW_CONSOLE+
                   NORMAL_PRIORITY_CLASS, // Prioritt
                   nil,                   // Environment
                   pchar(WorkDir),     // Verzeichnis
                   si,pi) then begin
//    while WaitForSingleObject(pi.hProcess,10)=WAIT_TIMEOUT do Application.ProcessMessages;
    if WaitTime=0 then begin  // wait for end
      while WaitForSingleObject(pi.hProcess,100)<>WAIT_OBJECT_0 do Application.ProcessMessages;
      Result:=0;
      end
    else begin   // wait for timeout
      if WaitForSingleObject(pi.hProcess,1000*abs(WaitTime))<>WAIT_TIMEOUT then Result:=0
      else Result:=WAIT_TIMEOUT;
      end;
    if (Result=0) or IgnoreTimeout then begin
      if GetExitCodeProcess(pi.hProcess,ec) then begin
        if ec>0 then Result:=ec or UserError;  // return exit code
        end
      else ec:=GetLastError;
      end;

    CloseHandle(pi.hProcess); CloseHandle(pi.hThread);

    if not assigned(OutMemo) and ShowWin then begin
      frmShow:=TfrmShow.Create(Application);
      frmShow.memShow.Clear;
      end;

// After process creation, restore the saved STDOUT.
{      if not SetStdHandle(STD_OUTPUT_HANDLE, hSaveStdout) then begin
      ShowError('Re-redirecting Stdout failed'); exit;
      end;
      }
// Close the write end of the pipe before reading from the
// read end of the pipe.
    if not CloseHandle(hChildStdoutWr) and ShowWin then begin
      if ShowWin then ErrorDialog(rsExecuteError,rsCloseHandleError);
      Result:=E_HANDLE;
      exit;
      end;
    if (Result=0) or (Result and UserError<>0) then begin
      chBuf[BUFSIZE]:=#0; s:='';
  // Read output from the child process, and write to parent's STDOUT.
      while ReadFile(hChildStdoutRdDup,chBuf[0],BUFSIZE,dwRead,nil)
            and (dwRead=BUFSIZE) do s:=s+chBuf;
      if dwRead>0 then begin
        chBuf[dwread]:=#0;
        s:=s+chBuf;
        end;
      if assigned(OutMemo) then OutMemo.SetSelTextBuf(pchar(s))
      else if ShowWin then frmShow.memShow.SetSelTextBuf(pchar(s));
      end;
    CloseHandle(hChildStdoutRdDup);
// DOS-Ausgabe anzeigen
    if not assigned(OutMemo) and ShowWin then with frmShow do begin
      ShowText(WaitTime);
      Release;
      end;
    end
  else Result:=GetLastError;
  end;

{ ------------------------------------------------------------------- }
// Prozess starten, nicht auf Ende warten
// AShow = true  : Fenster anzeigen (siehe SW_SHOW)
//       = false : kein Fenster anzeigen (siehe SW_HIDE)
function StartProcess (CmdLine,WorkDir : string; AShow : boolean) : THandle;
var
  si        : TStartupInfo;
  pi        : TProcessInformation;
  pwd       : PChar;
begin
// Create process to start Program
  FillChar(si, SizeOf(TStartupInfo), 0);
  with si do begin
    cb := Sizeof(TStartupInfo);
    dwFlags := STARTF_USESTDHANDLES or STARTF_USESHOWWINDOW;
    if AShow then wShowWindow:=SW_SHOW else wShowWindow:=SW_HIDE;
    end;
  if length(WorkDir)>0 then pwd:=pchar(WorkDir) else pwd:=nil;

  if CreateProcess(nil,                // Anwendungsname
                   pchar(CmdLine),
                   nil,                // Security
                   nil,                // Security
                   true,               // use InheritHandles
                   NORMAL_PRIORITY_CLASS, // Prioritt
                   nil,                   // Environment
                   pwd,                   // Verzeichnis
                   si,pi) then begin
     Result:=pi.hProcess;
     end
   else Result:=0;
   end;

// Prozess als anderer Benutzer starten, nicht auf Ende warten
function StartProcessAsUser (UserName,Domain,Password,CmdLine,WorkDir : WideString;
                             AShow : boolean) : THandle;
var
  si        : TStartupInfoW;
  pi        : TProcessInformation;
  d,w       : PWideChar;
begin
// Create process to start Program
  FillChar(si, SizeOf(TStartupInfo), 0);
  with si do begin
    cb := Sizeof(TStartupInfo);
    dwFlags := STARTF_USESHOWWINDOW;
    if AShow then wShowWindow:=SW_SHOW else wShowWindow:=SW_HIDE;
    end;
  if length(Domain)=0 then d:=nil else d:=pwidechar(Domain);
  if length(WorkDir)=0 then w:=nil else w:=pwidechar(WorkDir);
  if CreateProcessWithLogonW (pwidechar(UserName),d,pwidechar(Password),
                   0,
                   nil,                   // Anwendungsname
                   pwidechar(CmdLine),    // command line
                   CREATE_DEFAULT_ERROR_MODE,
                   nil,                   // Environment
                   w,                     // Verzeichnis
                   si,pi) then begin
     Result:=pi.hProcess;
     end
   else Result:=0;
   end;

procedure StopProcess (h : THandle);
begin
  TerminateProcess(h,0);
  CloseHandle(h);
  end;

end.

