(* Delphi Unit
   strings of units to be localized
   German version

    Dr. J. Rathlev, D-24222 Schwentinental (info(a)rathlev-home.de)

   The contents of this file may be used under the terms of the
   Mozilla Public License ("MPL") or
   GNU Lesser General Public License Version 2 or later (the "LGPL")

   Software distributed under this License is distributed on an "AS IS" basis,
   WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
   the specific language governing rights and limitations under the License.

   Vers. 1 - Dec. 2011
   *)

unit UnitStrings;

interface

{ ------------------------------------------------------------------- }
// Strings from FTPFileTools
function rsFtpConn : string;
function rsTryConnect : string;
function rsConnected : string;
function rsConnectErr : string;
function rsFtpHint : string;
function rsProxyHint : string;

// Strings from NumberUtils
function rsHexError : string;
function rsOctError : string;
function rsBinError : string;
function rsErrCopy : string;
function rsBytes : string;
function rsKBytes : string;
function rsMBytes : string;
function rsGBytes : string;
function rsUnknownError : string;
function rsWindowsError : string;
function rsStorageError : string;
function rsRpcError : string;
function rsInterfaceError : string;
function rsDispatchError : string;
function rsPreWin32Error : string;
function GetBytePrefixes : string;

// Strings from LangUtils
function rsSystemDefault : string;
function rsLangRestart : string;

// Strings from MathExp
function MathExpErrors (Error: Integer) : string;

// Strings from TextFilter
function rsIllRegExp : string;
function rsIllmask : string;

// Strings from WinExecute
function rsExecuteError : string;
function rsCreatePipeError : string;
function rsDupHandleError : string;
function rsCloseHandleError : string;

// Strings from CpDrv
function rsNoError : string;
function rsOpenError : string;
function rsStateError : string;
function rsFlushError : string;
function rsSetupError : string;

// Misc.
function rsVersion : string;
function rsLongCopyRight (const Year : string) : string;
function rsCopyRight (const Year : string) : string; overload;
function rsCopyRight : string; overload;
function rsNotAvail : string;
function rsConnectTo : string;
function rsUnknown : string;

implementation

uses SysUtils, DateUtils;

{ ------------------------------------------------------------------- }
// Strings from FTPFileTools
function rsFtpConn : string;
begin
  Result:='FTP-Verbindung';
  end;

function rsTryConnect : string;
begin
  Result:='Verbindung zu FTP-Server wird aufgebaut';
  end;

function rsConnected : string;
begin
  Result:='Verbindung zum FTP-Server ist aufgebaut';
  end;

function rsConnectErr : string; 
begin
  Result:='Die FTP-Verbindung zum Server ist fehlgeschlagen';
  end;

// Aufruf: Format(rsFtpHint,[host,port,user])
function rsFtpHint : string;
begin
  Result:='Die Verbindung zum FTP-Server: %s:%u'+sLineBreak+'fr den Benutzer: %s'+sLineBreak+'erfordert ein Kennwort!';
  end;

function rsProxyHint : string;
begin
  Result:='Die Verbindung zum FTP-Proxy-Server: %s:%u'+sLineBreak+'fr den Benutzer: %s'+sLineBreak+'erfordert ein Kennwort!';
  end;

{ ------------------------------------------------------------------- }
// Strings from JrUtils
function rsHexError : string;
begin
  Result:='%s ist kein gltiger Hexwert';
  end;

function rsOctError : string;
begin
  Result:='&s ist kein gltiger Oktal-Wert';
  end;

function rsBinError : string;
begin
  Result:='&s ist kein gltiger Binr-Wert';
  end;

function rsErrCopy : string;
begin
  Result:='Fehler beim Kopieren der Datei nach'+sLineBreak+'%s';
  end;

function rsBytes : string;
begin
  Result:='B';
  end;

function rsKBytes : string;
begin
  Result:='kB';
  end;

function rsMBytes : string;
begin
  Result:='MB';
  end;

function rsGBytes : string;
begin
  Result:='GB';
  end;

function rsUnknownError : string;
begin
  Result:='Unbekannter Systemfehler';
  end;

function rsWindowsError : string;
begin
  Result:='Windows-Fehler';
  end;

function rsStorageError : string;
begin
  Result:='Storage-Fehler';
  end;

function rsRpcError : string;
begin
  Result:='Fehler beim Remote Procedure Call';
  end;

function rsInterfaceError : string;
begin
  Result:='Interface-Fehler';
  end;

function rsDispatchError : string;
begin
  Result:='Dispatch-Fehler';
  end;

function rsPreWin32Error : string;
begin
  Result:='Fehler in SHFileOperation';
  end;

function GetBytePrefixes : string;
begin
  Result:='kMGT';
  end;

{ ------------------------------------------------------------------- }
// Strings from LangUtils
function rsSystemDefault : string;
begin
  Result:='&System-Standard';
  end;

function rsLangRestart : string;
begin
  Result:='Der Wechsel der Sprache erfordert einen Neustart des Programms!';
  end;

{ ------------------------------------------------------------------- }
// Strings from MathExp

function MathExpErrors (Error: Integer) : string;
begin
  case Error of
  0 : Result:= ' ';
  1 : Result:='Fehler (ffnende/schlieende Klammern)';
  2 : Result:='Eingabefehler (fehlende ffnende Klammer)';
  3 : Result:='Eingabefehler (kein Klammerinhalt)';
  4 : Result:='Division durch Null';
  5 : Result:='Unzulssiges Argument';
  6 : Result:='Operation fhrt zu berlauf';
  7 : Result:='Ungltiger Ausdruck';
  8 : Result:='Unerwarteter Operator';
  9 : Result:='Unvollstndiger Ausdruck';
  10 : Result:='Fehlender Operator';
  11 : Result:='Potenz mit unzulssiger (negativer) Basis';
  12 : Result:='"Null hoch Null"';
  13 : Result:='"Null durch Null"';
  14 : Result:='Unzulssige Kombination von Operanden';
  15 : Result:='Unzulssiges Zeichen';
  19 : Result:='Unzulssiges Argument (berlaufgefahr)';
  20 : Result:='Speicherplatz fehlt ("stack overflow")';
  30 : Result:='Speicherplatz fehlt ("string overflow")';
  else Result:='Unbekannter Fehler';
    end;
  end;

{ ------------------------------------------------------------------- }
// Strings from TextFilter
function rsIllRegExp : string;
begin
  Result:='Ungltiger regulrer Ausdruck!';
  end;

function rsIllmask : string;
begin
  Result:='Ungltiger Maske!';
  end;

{ ------------------------------------------------------------------- }
// Strings from WinExecute
function rsExecuteError : string;
begin
  Result:='Fehler beim Ausfhren eines Prozesses';
  end;

function rsCreatePipeError : string;
begin
  Result:='Erzeugung einer Pipe fr StdOut ist fehlgeschlagen';
  end;

function rsDupHandleError : string;
begin
  Result:='Die Funktion DuplicateHandle ist fehlgeschlagen';
  end;

function rsCloseHandleError : string;
begin
  Result:='Das Schlieen eines Handle ist fehlgeschlagen';
  end;

{ ------------------------------------------------------------------- }
// Strings from CpDrv
function rsNoError : string;
begin
  Result:='Keine Fehler bei COM-Verbindung';
  end;

function rsOpenError : string;
begin
  Result:='Fehler beim ffnen des COM-Ports';
  end;

function rsStateError : string;
begin
  Result:='Fehler beim Setzen des COM-Port-Status';
  end;

function rsFlushError : string;
begin
  Result:='Fehler beim Leeren der COM-Puffer';
  end;

function rsSetupError : string;
begin
  Result:='Fehler beim Initialisieren des COM-Ports';
  end;

{ ------------------------------------------------------------------- }
// Misc.
function rsVersion : string;
begin
  Result:='Vers.';
  end;

function rsLongCopyRight (const Year : string) : string;
begin
  Result:=' '+Year+' Dr. J. Rathlev'+sLineBreak+'D-24222 Schwentinental';
  end;

function rsCopyRight (const Year : string) : string;
begin
  rsCopyRight:=' '+Year+' Dr. J. Rathlev';
  end;

function rsCopyRight : string;
begin
  rsCopyRight(IntToStr(YearOf(Now)));
  end;

function rsNotAvail : string;
begin
  Result:='nicht verfgbar';
  end;

function rsConnectTo : string;
begin
  Result:='Verbinden mit ..';
  end;

function rsUnknown : string;
begin
  Result:='<Unbekannt>';
  end;

end.
